@@ -43,8 +43,8 @@
 #define THUMB_BORDER   13
 #define ROW_SPACING    14
 #define COL_SPACING    14
-#define ADD_LIST_DELAY 75
-#define ADD_LIST_CHUNK 333
+#define ADD_LIST_DELAY 50
+#define ADD_LIST_CHUNK 250
 #define SCROLL_DELAY   20
 
 enum {
@@ -308,6 +308,16 @@ gth_file_list_class_init (GthFileListClass *class)
 }
 
 
+static void
+update_thumbnails__step2 (gpointer data)
+{
+	GthFileList *file_list = data;
+
+	file_list->starting_update = FALSE;
+	gth_file_list_restart_thumbs (file_list, TRUE);
+}
+
+
 static gboolean
 update_thumbnails_cb (gpointer data)
 {
@@ -315,11 +325,12 @@ update_thumbnails_cb (gpointer data)
 
 	if (file_list->scroll_timer != 0)
 		g_source_remove (file_list->scroll_timer);
-
-	gth_file_list_restart_thumbs (file_list, TRUE);
-
 	file_list->scroll_timer = 0;
 
+	gth_file_list_interrupt_thumbs (file_list,
+					update_thumbnails__step2,
+					file_list);
+
 	return FALSE;
 }
 
@@ -328,14 +339,19 @@ static gboolean
 file_list_adj_value_changed (GtkAdjustment *adj, 
 			     GthFileList   *file_list)
 {	
+	if (image_list_is_frozen (IMAGE_LIST (file_list->ilist)))
+		return FALSE;
+
+	if (file_list->starting_update)
+		return FALSE;
+
+	file_list->starting_update = TRUE;
+
 	if (file_list->scroll_timer != 0) {
 		g_source_remove (file_list->scroll_timer);
 		file_list->scroll_timer = 0;
 	}
 
-	if (image_list_is_frozen (IMAGE_LIST (file_list->ilist)))
-		return FALSE;
-
 	file_list->scroll_timer = g_timeout_add (SCROLL_DELAY,
 						 update_thumbnails_cb,
 						 file_list);
@@ -372,6 +388,8 @@ gth_file_list_init (GthFileList *file_list)
 	file_list->interrupt_done_data = NULL;
 	file_list->scroll_timer      = 0;
 
+	file_list->starting_update   = FALSE;
+
 	if (unknown_pixbuf == NULL)
 		unknown_pixbuf = gdk_pixbuf_new_from_inline (-1, unknown_48_rgba, FALSE, NULL);
 	else
@@ -553,6 +571,8 @@ set_list__get_file_info_done_cb (GnomeVFSAsyncHandle *handle,
 	GList           *scan;
 	DoneFunc         done_func;
 
+	g_print ("GetFileInfo [DONE]\n");
+
 	g_signal_emit (G_OBJECT (file_list), gth_file_list_signals[IDLE], 0);
 
 	if (file_list->interrupt_set_list) {
@@ -580,11 +600,15 @@ set_list__get_file_info_done_cb (GnomeVFSAsyncHandle *handle,
 		fd = file_data_new (full_path, info_result->file_info);
 		g_free (full_path);
 
-		file_data_update_comment (fd);
 		gfi_data->filtered = g_list_prepend (gfi_data->filtered, fd);
 	}
 
+	g_print ("FileDataNew [DONE]\n");
+
 	image_list_clear (IMAGE_LIST (file_list->ilist));
+
+	g_print ("ImageListClear [DONE]\n");
+
 	add_list_in_chunks (gfi_data);
 }
 
@@ -607,6 +631,8 @@ set_list__step2 (GetFileInfoData *gfi_data)
 
  	gth_file_list_free_list (file_list);
 
+	g_print ("GetFileInfo -->\n");
+
 	gnome_vfs_async_get_file_info (&handle,
 				       gfi_data->uri_list,
 				       (GNOME_VFS_FILE_INFO_DEFAULT 
@@ -692,6 +718,8 @@ add_list_in_chunks (gpointer callback_data)
 	DoneFunc         done_func;
 	int              i, n = ADD_LIST_CHUNK;
 
+	g_print ("AddListInChunk -->\n");
+
 	if (gfi_data->timeout_id != 0) {
 		g_source_remove (gfi_data->timeout_id);
 		gfi_data->timeout_id = 0;
@@ -707,6 +735,8 @@ add_list_in_chunks (gpointer callback_data)
 
 		get_file_info_data_free (gfi_data);
 
+		g_print ("AddListInChunk [DONE]\n");
+
 		return FALSE;
 	}
 
@@ -727,6 +757,8 @@ add_list_in_chunks (gpointer callback_data)
 			(*done_func) (gfi_data->done_func_data);
 		
 		get_file_info_data_free (gfi_data);
+
+		g_print ("AddListInChunk [DONE]\n");
 		
 		return FALSE;
 	}
@@ -741,6 +773,8 @@ add_list_in_chunks (gpointer callback_data)
 	for (i = 0, scan = gfi_data->filtered; (i < n) && scan; i++, scan = scan->next) {
 		FileData *fd = scan->data;
 		int       pos;
+
+		file_data_update_comment (fd);
 		
 		pos = image_list_append (IMAGE_LIST (ilist),
 					 unknown_pixbuf,
@@ -764,6 +798,8 @@ add_list_in_chunks (gpointer callback_data)
 	gfi_data->timeout_id = g_timeout_add (ADD_LIST_DELAY, 
 					      add_list_in_chunks, 
 					      gfi_data);
+
+	g_print ("AddListInChunk [DONE]\n");
 	
 	return FALSE;
 }
@@ -804,7 +840,6 @@ add_list__get_file_info_done_cb (GnomeVFSAsyncHandle *handle,
 		fd = file_data_new (full_path, info_result->file_info);
 		g_free (full_path);
 
-		file_data_update_comment (fd);
 		gfi_data->filtered = g_list_prepend (gfi_data->filtered, fd);
 	}
 
@@ -1277,8 +1312,8 @@ gth_file_list_enable_thumbs (GthFileList *file_list,
 
 void
 gth_file_list_set_progress_func (GthFileList *file_list,
-			    ProgressFunc func,
-			    gpointer data)
+				 ProgressFunc func,
+				 gpointer     data)
 {
 	g_return_if_fail (file_list != NULL);
 
