@@ -323,8 +323,6 @@ image_viewer_init (ImageViewer *viewer)
 	viewer->frame_delay = 0;
 	viewer->anim_id = 0;
 
-	viewer->iter = NULL;
-
 	viewer->loader = IMAGE_LOADER (image_loader_new (NULL, TRUE));
 	g_signal_connect (G_OBJECT (viewer->loader), 
 			  "done",
@@ -335,6 +333,9 @@ image_viewer_init (ImageViewer *viewer)
 			  G_CALLBACK (image_error),
 			  viewer);
 
+	viewer->anim = NULL;
+	viewer->iter = NULL;
+
 	viewer->zoom_level = 1.0;
 	viewer->zoom_quality = ZOOM_QUALITY_HIGH;
 	viewer->zoom_change = ZOOM_CHANGE_KEEP_PREV;
@@ -370,9 +371,9 @@ image_viewer_init (ImageViewer *viewer)
 	viewer->vadj = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 1.0, 0.0, 
 							   1.0, 1.0, 1.0));
 
-	g_object_ref (G_OBJECT (viewer->hadj));
+	g_object_ref (viewer->hadj);
 	gtk_object_sink (GTK_OBJECT (viewer->hadj));
-	g_object_ref (G_OBJECT (viewer->vadj));
+	g_object_ref (viewer->vadj);
 	gtk_object_sink (GTK_OBJECT (viewer->vadj));
 
 	g_signal_connect (G_OBJECT (viewer->hadj), 
@@ -421,7 +422,7 @@ paint (ImageViewer *viewer,
 	    || (viewer->area_bps != bits_per_sample)
 	    || (viewer->area_color_space != color_space)) {
 		if (viewer->area_pixbuf != NULL)
-			g_object_unref (G_OBJECT (viewer->area_pixbuf));
+			g_object_unref (viewer->area_pixbuf);
 		viewer->area_pixbuf = gdk_pixbuf_new (color_space,
 						      FALSE, 
 						      bits_per_sample,
@@ -1041,7 +1042,7 @@ create_first_pixbuf (ImageViewer *viewer)
 	viewer->frame_delay = 0;
 
 	if (viewer->iter != NULL)
-		g_object_unref (G_OBJECT (viewer->iter));
+		g_object_unref (viewer->iter);
 
 	g_get_current_time (&viewer->time);
 
@@ -1090,14 +1091,19 @@ image_viewer_finalize (GObject *object)
 		viewer->anim_id = 0;
 	}
 
-	if (viewer->iter != NULL) {
-		g_object_unref (G_OBJECT (viewer->iter));
-		viewer->iter = NULL;
+	if (viewer->loader != NULL) {
+		g_object_unref (viewer->loader);
+		viewer->loader = NULL;
 	}
 
-	if (viewer->loader != NULL) {
-		g_object_unref (G_OBJECT (viewer->loader));
-		viewer->loader = NULL;
+	if (viewer->anim != NULL) {
+		g_object_unref (viewer->anim);
+		viewer->anim = NULL;
+	}
+
+	if (viewer->iter != NULL) {
+		g_object_unref (viewer->iter);
+		viewer->iter = NULL;
 	}
 
 	if (viewer->cursor != NULL) {
@@ -1113,18 +1119,18 @@ image_viewer_finalize (GObject *object)
 	if (viewer->hadj != NULL) {
 		g_signal_handlers_disconnect_by_data (G_OBJECT (viewer->hadj),
 						      viewer);
-		g_object_unref (G_OBJECT (viewer->hadj));
+		g_object_unref (viewer->hadj);
 		viewer->hadj = NULL;
 	}
 	if (viewer->vadj != NULL) {
 		g_signal_handlers_disconnect_by_data (G_OBJECT (viewer->vadj),
 						      viewer);
-		g_object_unref (G_OBJECT (viewer->vadj));
+		g_object_unref (viewer->vadj);
 		viewer->vadj = NULL;
 	}
 	
 	if (viewer->area_pixbuf != NULL) {
-		g_object_unref (G_OBJECT (viewer->area_pixbuf));
+		g_object_unref (viewer->area_pixbuf);
 		viewer->area_pixbuf = NULL;
 	}
 
@@ -1261,6 +1267,7 @@ image_viewer_size_allocate (GtkWidget       *widget,
 {
 	ImageViewer *viewer;
 	int          gdk_width, gdk_height;
+	GdkPixbuf   *current_pixbuf;
 
 	viewer = IMAGE_VIEWER (widget);
 
@@ -1268,24 +1275,20 @@ image_viewer_size_allocate (GtkWidget       *widget,
 	gdk_width = allocation->width - FRAME_BORDER2; 
 	gdk_height = allocation->height - FRAME_BORDER2;
 
+	current_pixbuf = image_viewer_get_current_pixbuf (viewer);
+
 	/* If zoom_fit is active update the zoom level. */
 
-	if (! viewer->is_void 
-	    && viewer->zoom_fit
-	    && (image_viewer_get_current_pixbuf (viewer) != NULL)) 
+	if (! viewer->is_void && viewer->zoom_fit && (current_pixbuf != NULL)) 
 		zoom_to_fit (viewer);
 
 	/* If zoom_fit_if_larger is active update the zoom level. */
 
 	if (! viewer->is_void 
 	    && viewer->zoom_fit_if_larger
-	    && (image_viewer_get_current_pixbuf (viewer) != NULL)) {
-		GdkPixbuf *buf;
-		
-		buf = image_viewer_get_current_pixbuf (viewer);
-		
-		if ((gdk_width < gdk_pixbuf_get_width (buf))
-		    || (gdk_height < gdk_pixbuf_get_height (buf))) 
+	    && (current_pixbuf != NULL)) {
+		if ((gdk_width < gdk_pixbuf_get_width (current_pixbuf))
+		    || (gdk_height < gdk_pixbuf_get_height (current_pixbuf))) 
 			zoom_to_fit (viewer);
 		else {
 			viewer->doing_zoom_fit = TRUE;
@@ -1296,8 +1299,8 @@ image_viewer_size_allocate (GtkWidget       *widget,
 
 	/* Check whether the offset is still valid. */
 
-	if (image_viewer_get_current_pixbuf (viewer) != NULL) {
-		gint width, height;
+	if (current_pixbuf != NULL) {
+		int width, height;
 		
 		get_zoomed_size (viewer, &width, &height, viewer->zoom_level);
 
@@ -1729,6 +1732,9 @@ init_animation (ImageViewer *viewer)
 	if (! viewer->is_animation) 
 		return;
 
+	if (viewer->anim != NULL)
+		g_object_unref (viewer->anim);
+
 	viewer->anim = image_loader_get_animation (viewer->loader);
 	if (viewer->anim == NULL) {
 		viewer->is_animation = FALSE;
@@ -1806,6 +1812,7 @@ image_error (ImageLoader *il,
 	ImageViewer *viewer = data;
 
 	image_viewer_set_void (viewer);
+
 	g_signal_emit (G_OBJECT (viewer), 
 		       image_viewer_signals[IMAGE_LOADED], 
 		       0);
@@ -1821,9 +1828,14 @@ image_loaded (ImageLoader *il,
 
 	halt_animation (viewer);
 
-	viewer->anim = NULL;
+	if (viewer->anim != NULL) {
+		g_object_unref (viewer->anim);
+		viewer->anim = NULL;
+	}
+
 	anim = image_loader_get_animation (viewer->loader);
 	viewer->is_animation = (anim != NULL) && ! gdk_pixbuf_animation_is_static_image (anim);
+	g_object_unref (anim);
 
 	if (viewer->is_animation)
 		init_animation (viewer);
@@ -1833,22 +1845,22 @@ image_loaded (ImageLoader *il,
 		image_viewer_set_zoom (viewer, 1.0);
 		add_change_frame_timeout (viewer);
 		break;
-
+		
 	case ZOOM_CHANGE_FIT:
 		image_viewer_zoom_to_fit (viewer);
 		add_change_frame_timeout (viewer);
 		break;
-
+		
 	case ZOOM_CHANGE_KEEP_PREV:
 		image_viewer_update_view (viewer);
 		break;
-
+		
 	case ZOOM_CHANGE_FIT_IF_LARGER:
 		image_viewer_zoom_to_fit_if_larger (viewer);
 		add_change_frame_timeout (viewer);
 		break;
 	}
-
+	
 	g_signal_emit (G_OBJECT (viewer), 
 		       image_viewer_signals[IMAGE_LOADED], 
 		       0);
@@ -2241,7 +2253,7 @@ set_scroll_adjustments (GtkWidget *widget,
         if (viewer->hadj && viewer->hadj != hadj) {
 		g_signal_handlers_disconnect_by_data (G_OBJECT (viewer->hadj),
 						      viewer);
-		g_object_unref (G_OBJECT (viewer->hadj));
+		g_object_unref (viewer->hadj);
 
 		viewer->hadj = NULL;
         }
@@ -2249,13 +2261,13 @@ set_scroll_adjustments (GtkWidget *widget,
         if (viewer->vadj && viewer->vadj != vadj) {
 		g_signal_handlers_disconnect_by_data (G_OBJECT (viewer->vadj),
 						      viewer);
-		g_object_unref (G_OBJECT (viewer->vadj));
+		g_object_unref (viewer->vadj);
 		viewer->vadj = NULL;
         }
 
         if (viewer->hadj != hadj) {
                 viewer->hadj = hadj;
-                g_object_ref (G_OBJECT (viewer->hadj));
+                g_object_ref (viewer->hadj);
                 gtk_object_sink (GTK_OBJECT (viewer->hadj));
 
 		g_signal_connect (G_OBJECT (viewer->hadj), 
@@ -2266,7 +2278,7 @@ set_scroll_adjustments (GtkWidget *widget,
 
         if (viewer->vadj != vadj) {
 		viewer->vadj = vadj;
-		g_object_ref (G_OBJECT (viewer->vadj));
+		g_object_ref (viewer->vadj);
 		gtk_object_sink (GTK_OBJECT (viewer->vadj));
 
 		g_signal_connect (G_OBJECT (viewer->vadj), 
@@ -2311,6 +2323,7 @@ scroll_signal (GtkWidget     *widget,
 		break;
 	default:
 		xstep = 0;
+		break;
 	}
 
 	switch (yscroll_type) {
@@ -2328,6 +2341,7 @@ scroll_signal (GtkWidget     *widget,
 		break;
 	default:
 		ystep = 0;
+		break;
 	}
 
 	scroll_relative (viewer, xstep, ystep);
